@@ -3,6 +3,7 @@ import subprocess
 import socket
 from plato.models.task import CustomEvalConfig
 from plato.models import PlatoTask, EvaluationResult
+from plato.models.flow import Flow
 from typing import Coroutine, List, Optional, Type, Dict, Any, TYPE_CHECKING
 import time
 import asyncio
@@ -11,6 +12,7 @@ import logging
 from plato.exceptions import PlatoClientError
 from playwright.async_api import Page
 import yaml
+import json
 from urllib.parse import urlparse
 from pathlib import Path
 
@@ -72,51 +74,75 @@ class PlatoEnvironment:
         throw_on_login_error: bool = False,
         screenshots_dir: Optional[Path] = None,
         dataset: str = "base",
+        from_api: bool = False,
     ) -> None:
         """Login to the environment using authentication config.
 
         Args:
             page (Page): The Playwright page to authenticate
         """
-        from plato.models.flow import Simulator
         from plato.flow_executor import FlowExecutor
 
-        if not self.env_id:
-            raise PlatoClientError("No env_id set on environment; cannot load flows")
+        if from_api:
+            # Fetch flows from API for this environment/job
+            try:
+                headers = {"X-API-Key": self._client.api_key}
+                async with self._client.http_session.get(
+                    f"{self._client.base_url}/env/{self.id}/flows",
+                    headers=headers,
+                ) as resp:
+                    await self._client._handle_response_error(resp)  # type: ignore[attr-defined]
+                    body_text = await resp.text()
+                    # Endpoint may return JSON with { data: { flows: "...yaml..." } } or raw YAML
+                    try:
+                        parsed = json.loads(body_text)
+                        flows_yaml = (
+                            parsed.get("data", {}).get("flows")
+                            if isinstance(parsed, dict)
+                            else None
+                        )
+                        if not flows_yaml:
+                            raise ValueError("flows missing in JSON body")
+                    except Exception:
+                        flows_yaml = body_text
+                    scripts = yaml.safe_load(flows_yaml)
+            except Exception as e:
+                raise PlatoClientError(f"Failed to load flows from API: {e}")
+        else:
+            if not self.env_id:
+                raise PlatoClientError(
+                    "No env_id set on environment; cannot load flows"
+                )
 
-        # Load from repo path: python/src/plato/flows/{env_id}/scripts.yaml
-        flows_dir = os.path.join(os.path.dirname(os.path.dirname(__file__)), "flows")
-        scripts_path = os.path.join(flows_dir, self.env_id, "scripts.yaml")
-        if not os.path.exists(scripts_path):
-            raise PlatoClientError(
-                f"Flow scripts not found for env_id '{self.env_id}' at {scripts_path}"
+            # Load from repo path: python/src/plato/flows/{env_id}/scripts.yaml
+            flows_dir = os.path.join(
+                os.path.dirname(os.path.dirname(__file__)), "flows"
             )
-        with open(scripts_path, "r") as f:
-            scripts = yaml.safe_load(f)
-        simulator = Simulator.model_validate(scripts)
+            scripts_path = os.path.join(flows_dir, self.env_id, "scripts.yaml")
+            if not os.path.exists(scripts_path):
+                raise PlatoClientError(
+                    f"Flow scripts not found for env_id '{self.env_id}' at {scripts_path}"
+                )
+            with open(scripts_path, "r") as f:
+                scripts = yaml.safe_load(f)
 
-        # Get base dataset and login flow
-        base_dataset = next(
-            (ds for ds in simulator.datasets if ds.name == dataset), None
-        )
-        if not base_dataset:
-            raise PlatoClientError("No dataset found")
+        # Parse flows from Watchdog-style format
+        flows_data = scripts.get("flows", [])
+        flows_list = [Flow.model_validate(f) for f in flows_data]
 
+        # Get login flow (default to "login" if dataset is "base")
         if dataset == "base":
             flow_name = "login"
         else:
             flow_name = dataset
 
-        login_flow = next(
-            (flow for flow in simulator.flows if flow.name == flow_name), None
-        )
+        login_flow = next((flow for flow in flows_list if flow.name == flow_name), None)
         if not login_flow:
-            raise PlatoClientError("No login flow found")
+            raise PlatoClientError(f"No flow named '{flow_name}' found")
 
         flow_executor = FlowExecutor(
             page,
             login_flow,
-            base_dataset,
             logger=logger,
             screenshots_dir=screenshots_dir,
         )
@@ -237,6 +263,7 @@ class PlatoEnvironment:
         self,
         task: Optional[PlatoTask] = None,
         agent_version: Optional[str] = None,
+        model: Optional[str] = None,
         load_authenticated: bool = False,
         **kwargs,
     ) -> str:
@@ -251,7 +278,7 @@ class PlatoEnvironment:
             str: The environment is reset and a new run session is created.
         """
         response = await self._client.reset_environment(
-            self.id, task, agent_version, load_authenticated, **kwargs
+            self.id, task, agent_version, model, load_authenticated, **kwargs
         )
         if task:
             self._current_task = task
