@@ -1,5 +1,5 @@
 from datetime import datetime
-from typing import List, Optional, Dict, Any, Literal
+from typing import List, Optional, Dict, Any
 from plato.config import get_config
 from plato.models import PlatoTask, PlatoTaskMetadata, PlatoEnvironment
 from plato.models.task import ScoringType
@@ -25,18 +25,28 @@ class Plato:
     Attributes:
         api_key (str): The API key used for authentication with Plato API.
         base_url (str): The base URL of the Plato API.
+        feature_flags (Dict[str, Any]): Feature flags to include in all requests.
         http_session (Optional[aiohttp.ClientSession]): The aiohttp session for making HTTP requests.
     """
 
-    def __init__(self, api_key: Optional[str] = None, base_url: Optional[str] = None):
+    def __init__(
+        self,
+        api_key: Optional[str] = None,
+        base_url: Optional[str] = None,
+        feature_flags: Optional[Dict[str, Any]] = None,
+    ):
         """Initialize a new Plato.
 
         Args:
             api_key (Optional[str]): The API key for authentication. If not provided,
                 falls back to the key from config.
+            base_url (Optional[str]): The base URL for the Plato API. If not provided,
+                falls back to the URL from config.
+            feature_flags (Optional[Dict[str, Any]]): Feature flags to include in all requests.
         """
         self.api_key = api_key or config.api_key
         self.base_url = base_url or config.base_url
+        self.feature_flags = feature_flags or {}
         self._http_session: Optional[aiohttp.ClientSession] = None
 
     @property
@@ -58,7 +68,18 @@ class Plato:
                 sock_read=600,  # 10 minutes
                 sock_connect=60,
             )
-            self._http_session = aiohttp.ClientSession(timeout=timeout)
+            cookie_jar = aiohttp.CookieJar(unsafe=True)
+            self._http_session = aiohttp.ClientSession(
+                timeout=timeout, cookie_jar=cookie_jar
+            )
+            # Attach feature flags as default cookies for all requests, scoped to base_url
+            if self.feature_flags:
+                from yarl import URL
+
+                cookie_jar.update_cookies(
+                    {name: str(value) for name, value in self.feature_flags.items()},
+                    response_url=URL(self.base_url),
+                )
         return self._http_session
 
     async def close(self):
@@ -108,7 +129,6 @@ class Plato:
         tag: Optional[str] = None,
         dataset: Optional[str] = None,
         artifact_id: Optional[str] = None,
-        feature_flags: Optional[Dict[str, Any]] = None,
     ) -> PlatoEnvironment:
         """Create a new Plato environment for the given task.
 
@@ -133,27 +153,29 @@ class Plato:
             aiohttp.ClientError: If the API request fails.
         """
         headers = {"X-API-Key": self.api_key}
+        url = f"{self.base_url}/env/make2"
+        request_data = {
+            "interface_type": interface_type or "noop",
+            "interface_width": viewport_width,
+            "interface_height": viewport_height,
+            "source": "SDK",
+            "open_page_on_start": open_page_on_start,
+            "env_id": env_id,
+            "tag": tag,
+            "dataset": dataset,
+            "artifact_id": artifact_id,
+            "env_config": env_config or {},
+            "record_network_requests": record_network_requests,
+            "record_actions": record_actions,
+            "keepalive": keepalive,
+            "alias": alias,
+            "fast": fast,
+            "version": version,
+        }
+
         async with self.http_session.post(
-            f"{self.base_url}/env/make2",
-            json={
-                "interface_type": interface_type or "noop",
-                "interface_width": viewport_width,
-                "interface_height": viewport_height,
-                "source": "SDK",
-                "open_page_on_start": open_page_on_start,
-                "env_id": env_id,
-                "tag": tag,
-                "dataset": dataset,
-                "artifact_id": artifact_id,
-                "env_config": env_config or {},
-                "record_network_requests": record_network_requests,
-                "record_actions": record_actions,
-                "keepalive": keepalive,
-                "alias": alias,
-                "fast": fast,
-                "version": version,
-            },
-            cookies={name: str(value) for name, value in (feature_flags or {}).items()},
+            url,
+            json=request_data,
             headers=headers,
         ) as response:
             await self._handle_response_error(response)
@@ -266,6 +288,7 @@ class Plato:
         job_id: str,
         task: Optional[PlatoTask] = None,
         agent_version: Optional[str] = None,
+        model: Optional[str] = None,
         load_authenticated: bool = False,
         **kwargs,
     ) -> Dict[str, Any]:
@@ -287,6 +310,7 @@ class Plato:
         body = {
             "test_case_public_id": task.public_id if task else None,
             "agent_version": agent_version,
+            "model": model,
             "load_browser_state": load_authenticated,
             **kwargs,
         }
@@ -512,7 +536,7 @@ class Plato:
         """
         headers = {"X-API-Key": self.api_key}
         async with self.http_session.get(
-            f"{self.base_url}/testcases?simulator_name={simulator_name}&page_size=1000",
+            f"{self.base_url}/testcases?simulator_name={simulator_name}&page_size=10000",
             headers=headers,
         ) as response:
             await self._handle_response_error(response)
@@ -538,12 +562,19 @@ class Plato:
                     is_sample=t.get("isSample", False),
                     simulator_artifact_id=t.get("simulatorArtifactId"),
                     metadata=PlatoTaskMetadata(
-                        reasoning_level=t.get("metadataConfig", {}).get("reasoningLevel"),
+                        reasoning_level=t.get("metadataConfig", {}).get(
+                            "reasoningLevel"
+                        ),
                         skills=t.get("metadataConfig", {}).get("skills", []),
-                        capabilities=t.get("metadataConfig", {}).get("capabilities", []),
+                        capabilities=t.get("metadataConfig", {}).get(
+                            "capabilities", []
+                        ),
                         tags=t.get("metadataConfig", {}).get("tags", []),
                         rejected=t.get("metadataConfig", {}).get("rejected", False),
-                    ) if t.get("metadataConfig") else None,
+                    )
+                    if t.get("metadataConfig")
+                    else None,
+                    version=t.get("version"),
                 )
                 for t in test_cases
             ]
@@ -739,3 +770,128 @@ class Plato:
         ) as response:
             await self._handle_response_error(response)
             return await response.json()
+
+    async def get_simulator_flows(self, artifact_id: str) -> List[Dict[str, Any]]:
+        """Get login flows for a simulator artifact.
+
+        This method fetches flow configurations from the API using a simulator artifact ID,
+        allowing you to retrieve login flows independently of an environment instance.
+
+        Args:
+            artifact_id (str): The simulator artifact ID to fetch flows for.
+
+        Returns:
+            List[Dict[str, Any]]: List of flow configurations parsed from the YAML response.
+
+        Raises:
+            PlatoClientError: If the API request fails or flows cannot be parsed.
+            aiohttp.ClientError: If the API request fails.
+
+        Example:
+            ```python
+            client = Plato()
+            flows = await client.get_simulator_flows("artifact_123")
+            # Use the flows for authentication
+            ```
+        """
+        import yaml
+        import json
+
+        try:
+            headers = {"X-API-Key": self.api_key}
+            async with self.http_session.get(
+                f"{self.base_url}/simulator/{artifact_id}/flows", headers=headers
+            ) as resp:
+                await self._handle_response_error(resp)
+                body_text = await resp.text()
+
+                # Endpoint may return JSON with { data: { flows: "...yaml..." } } or raw YAML
+                try:
+                    parsed = json.loads(body_text)
+                    flows_yaml = (
+                        parsed.get("data", {}).get("flows")
+                        if isinstance(parsed, dict)
+                        else None
+                    )
+                    if not flows_yaml:
+                        raise ValueError("flows missing in JSON body")
+                except Exception:
+                    flows_yaml = body_text
+
+                scripts = yaml.safe_load(flows_yaml)
+                flows_data = scripts.get("flows", [])
+                return flows_data
+        except Exception as e:
+            raise PlatoClientError(f"Failed to load flows from API: {e}")
+
+    async def login_artifact(
+        self,
+        artifact_id: str,
+        page,
+        throw_on_login_error: bool = False,
+        screenshots_dir: Optional[Any] = None,
+        dataset: str = "base",
+    ) -> None:
+        """Login using flows from a simulator artifact.
+
+        This method fetches flow configurations from the API using a simulator artifact ID
+        and executes the login flow on the provided Playwright page. This is independent
+        of any environment instance.
+
+        Args:
+            artifact_id (str): The simulator artifact ID to fetch flows for.
+            page: The Playwright page to authenticate (async_api.Page).
+            throw_on_login_error (bool): Whether to raise an error on login failure.
+            screenshots_dir (Optional[Path]): Directory to store screenshots during the flow.
+            dataset (str): The dataset/flow name to use for login (default: "base", which maps to "login").
+
+        Raises:
+            PlatoClientError: If flows cannot be fetched, parsed, or executed.
+
+        Example:
+            ```python
+            from plato.sdk import Plato
+            from playwright.async_api import async_playwright
+
+            client = Plato()
+            async with async_playwright() as p:
+                browser = await p.chromium.launch()
+                page = await browser.new_page()
+                await client.login_artifact("artifact_123", page)
+                # Page is now authenticated
+            ```
+        """
+        from plato.flow_executor import FlowExecutor
+        from plato.models.flow import Flow
+        from pathlib import Path
+
+        try:
+            flows_data = await self.get_simulator_flows(artifact_id)
+            flows_list = [Flow.model_validate(f) for f in flows_data]
+
+            # Determine flow name based on dataset
+            if dataset == "base":
+                flow_name = "login"
+            else:
+                flow_name = dataset
+
+            login_flow = next(
+                (flow for flow in flows_list if flow.name == flow_name), None
+            )
+            if not login_flow:
+                raise PlatoClientError(f"No login flow '{flow_name}' found")
+
+            flow_executor = FlowExecutor(
+                page, login_flow, logger=logger, screenshots_dir=screenshots_dir
+            )
+            success = await flow_executor.execute_flow()
+            if not success:
+                if throw_on_login_error:
+                    raise PlatoClientError("Failed to login")
+                else:
+                    logger.warning("Failed to login")
+        except Exception as e:
+            if throw_on_login_error:
+                raise PlatoClientError(f"Login failed: {e}")
+            else:
+                logger.error(f"Login failed: {e}")
