@@ -3,9 +3,8 @@ Synchronous flow execution engine for Plato simulator testing.
 Uses Pydantic models for type safety and validation.
 """
 
-import time
 import logging
-from typing import Dict, List, Optional, Any, Union
+from typing import Optional
 from pathlib import Path
 import sys
 import os
@@ -13,8 +12,8 @@ from urllib.parse import urljoin
 sys.path.insert(0, os.path.dirname(__file__))
 
 from playwright.sync_api import Page
-from models.flow import (
-    FlowStep, Simulator, Dataset, Flow,
+from plato.models.flow import (
+    FlowStep, Flow,
     WaitForSelectorStep, ClickStep, FillStep, WaitStep, NavigateStep,
     WaitForUrlStep, CheckElementStep, ScreenshotStep, VerifyTextStep,
     VerifyUrlStep, VerifyNoErrorsStep, VerifyStep
@@ -23,94 +22,94 @@ from models.flow import (
 
 class SyncFlowExecutor:
     """Executes configurable flows for simulator interactions with Pydantic validation (synchronous)."""
-    
-    def __init__(self, page: Page, flow: Flow, dataset: Dataset, screenshots_dir: Optional[Path] = None, logger: logging.Logger = logging.getLogger(__name__)):
+
+    def __init__(self, page: Page, flow: Flow, screenshots_dir: Optional[Path] = None, logger: logging.Logger = logging.getLogger(__name__)):
         self.page = page
         self.flow = flow
-        self.dataset = dataset
+        
         self.screenshots_dir = screenshots_dir
         if self.screenshots_dir:
             self.screenshots_dir.mkdir(parents=True, exist_ok=True)
         self.base_url = None  # Will be set from the page URL after first navigation
         self.logger = logger
-        
+
     def _resolve_url(self, url: str) -> str:
         """Resolve a URL against the base URL if it's relative."""
         # If URL is absolute, return as is
         if url.startswith(('http://', 'https://')):
             return url
-            
+
         # If we don't have a base URL yet, get it from the current page
         if not self.base_url and self.page.url:
             self.base_url = self.page.url
-            
+
         # If we have a base URL, join with it
         if self.base_url:
             return urljoin(self.base_url, url)
-            
+
         # If no base URL available, return original URL
         return url
-    
+
     def execute_flow(self) -> bool:
         """
         Execute a named flow from the configuration.
-        
+
         Returns:
             bool: True if flow executed successfully, False otherwise
         """
-        
+
         steps = self.flow.steps
-        
+
         self.logger.info(f"🔄 Starting flow: {self.flow.name}")
         self.logger.info(f"📋 Flow description: {self.flow.description or 'No description'}")
         self.logger.info(f"🎯 Steps to execute: {len(steps)}")
-        
+
         try:
             for i, step in enumerate(steps, 1):
-                self.logger.info(f"🔸 Step {i}/{len(steps)}: {step.description or step.action}")
-                
+                self.logger.info(f"🔸 Step {i}/{len(steps)}: {step.description or step.type}")
+
                 success = self._execute_step(step)
                 if not success:
                     self.logger.error(f"❌ Flow '{self.flow.name}' failed at step {i}")
                     return False
-                    
+
             self.logger.info(f"✅ Flow '{self.flow.name}' completed successfully")
             return True
-            
+
         except Exception as e:
             self.logger.error(f"❌ Flow '{self.flow.name}' failed with exception: {e}")
             return False
-    
+
     def _execute_step(self, step: FlowStep) -> bool:
         """Execute a single step in a flow using action attribute."""
-        if step.action == "wait_for_selector":
+        if step.type == "wait_for_selector":
             return self._wait_for_selector(step)
-        elif step.action == "click":
+        elif step.type == "click":
             return self._click(step)
-        elif step.action == "fill":
+        elif step.type == "fill":
             return self._fill(step)
-        elif step.action == "wait":
+        elif step.type == "wait":
             return self._wait(step)
-        elif step.action == "navigate":
+        elif step.type == "navigate":
             return self._navigate(step)
-        elif step.action == "wait_for_url":
+        elif step.type == "wait_for_url":
             return self._wait_for_url(step)
-        elif step.action == "check_element":
+        elif step.type == "check_element":
             return self._check_element(step)
-        elif step.action == "verify":
+        elif step.type == "verify":
             return self._verify(step)
-        elif step.action == "screenshot":
+        elif step.type == "screenshot":
             return self._screenshot(step)
-        elif step.action == "verify_text":
+        elif step.type == "verify_text":
             return self._verify_text(step)
-        elif step.action == "verify_url":
+        elif step.type == "verify_url":
             return self._verify_url(step)
-        elif step.action == "verify_no_errors":
+        elif step.type == "verify_no_errors":
             return self._verify_no_errors(step)
         else:
-            self.logger.error(f"❌ Unknown step action: {step.action}")
+            self.logger.error(f"❌ Unknown step action: {step.type}")
             return False
-    
+
     def _wait_for_selector(self, step: WaitForSelectorStep) -> bool:
         """Wait for a selector to be present."""
         try:
@@ -120,7 +119,7 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ Selector not found: {step.selector} - {e}")
             return False
-    
+
     def _click(self, step: ClickStep) -> bool:
         """Click an element."""
         try:
@@ -131,25 +130,15 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ Failed to click: {step.selector} - {e}")
             return False
-    
+
     def _fill(self, step: FillStep) -> bool:
         """Fill an input field."""
-        value_ref = step.value
-        
-        # Resolve value from dataset variables if it's a reference
-        if isinstance(value_ref, str) and value_ref.startswith("$"):
-            variable_key = value_ref[1:]  # Remove $ prefix
-            value = self.dataset.variables.get(variable_key)
-            if value is None:
-                self.logger.error(f"❌ Dataset variable '{variable_key}' not found")
-                return False
-        else:
-            value = value_ref
-        
+        value = step.value
+
         try:
             self.page.wait_for_selector(step.selector, timeout=step.timeout)
             self.page.fill(step.selector, str(value))
-            
+
             # Log value safely (mask passwords)
             display_value = "*" * len(str(value)) if "password" in step.selector.lower() else str(value)
             self.logger.info(f"✅ Filled {step.selector} with: {display_value}")
@@ -157,7 +146,7 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ Failed to fill: {step.selector} - {e}")
             return False
-    
+
     def _wait(self, step: WaitStep) -> bool:
         """Wait for a specified duration."""
         try:
@@ -167,7 +156,7 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ Wait failed: {e}")
             return False
-    
+
     def _navigate(self, step: NavigateStep) -> bool:
         """Navigate to a URL."""
         try:
@@ -180,7 +169,7 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ Navigation failed: {step.url} - {e}")
             return False
-    
+
     def _wait_for_url(self, step: WaitForUrlStep) -> bool:
         """Wait for URL to contain specific text."""
         try:
@@ -193,13 +182,13 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ URL check failed: {step.url_contains} - {e}")
             return False
-    
+
     def _check_element(self, step: CheckElementStep) -> bool:
         """Check if an element exists (non-blocking)."""
         try:
             element = self.page.query_selector(step.selector)
             exists = element is not None
-            
+
             if step.should_exist and exists:
                 self.logger.info(f"✅ Element exists as expected: {step.selector}")
                 return True
@@ -212,11 +201,11 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ Element check error: {step.selector} - {e}")
             return False
-    
+
     def _verify(self, step: VerifyStep) -> bool:
         """Verify DOM state using multiple validation criteria."""
-        verification_type = step.type
-        
+        verification_type = step.verify_type
+
         if verification_type == "element_exists":
             return self._verify_element_exists(step)
         elif verification_type == "element_visible":
@@ -230,7 +219,7 @@ class SyncFlowExecutor:
         else:
             self.logger.error(f"❌ Unknown verification type: {verification_type}")
             return False
-    
+
     def _verify_element_exists(self, step: VerifyStep) -> bool:
         """Verify that an element exists in the DOM."""
         try:
@@ -244,7 +233,7 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ Verification error: {step.selector} - {e}")
             return False
-    
+
     def _verify_element_visible(self, step: VerifyStep) -> bool:
         """Verify that an element is visible on the page."""
         try:
@@ -263,7 +252,7 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ Verification error: {step.selector} - {e}")
             return False
-    
+
     def _verify_element_text(self, step: VerifyStep) -> bool:
         """Verify that an element contains specific text."""
         try:
@@ -294,13 +283,13 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ Verification error: {step.selector} - {e}")
             return False
-    
+
     def _verify_element_count(self, step: VerifyStep) -> bool:
         """Verify the count of elements matching a selector."""
         try:
             elements = self.page.query_selector_all(step.selector)
             actual_count = len(elements)
-            
+
             if actual_count == step.count:
                 self.logger.info(f"✅ Verification passed: Found {actual_count} elements matching '{step.selector}'")
                 return True
@@ -310,12 +299,12 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ Verification error: {step.selector} - {e}")
             return False
-    
+
     def _verify_page_title(self, step: VerifyStep) -> bool:
         """Verify the page title."""
         try:
             actual_title = self.page.title()
-            
+
             if step.contains:
                 if step.title in actual_title:
                     self.logger.info(f"✅ Verification passed: Page title contains '{step.title}'")
@@ -333,16 +322,15 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ Verification error: {e}")
             return False
-    
+
     def _screenshot(self, step: ScreenshotStep) -> bool:
         """Take a screenshot for visual verification."""
         try:
             # Add timestamp to filename for chronological sorting
-            import datetime
             import time
             # Use epoch time in milliseconds for guaranteed chronological sorting
             timestamp_ms = int(time.time() * 1000)
-            
+
             # Extract base name and extension
             filename = step.filename
             if '.' in filename:
@@ -350,7 +338,7 @@ class SyncFlowExecutor:
                 timestamped_filename = f"{timestamp_ms}_{name}.{ext}"
             else:
                 timestamped_filename = f"{timestamp_ms}_{filename}.png"
-            
+
             # Save screenshot to the proper directory
             if self.screenshots_dir:
                 screenshot_path = self.screenshots_dir / timestamped_filename
@@ -360,13 +348,13 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ Screenshot failed: {e}")
             return False
-    
+
     def _verify_text(self, step: VerifyTextStep) -> bool:
         """Verify that specific text appears anywhere on the page."""
         try:
             page_content = self.page.content()
             text_found = step.text in page_content
-            
+
             if step.should_exist and text_found:
                 self.logger.info(f"✅ Verification passed: Text '{step.text}' found on page")
                 return True
@@ -382,12 +370,12 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ Text verification error: {e}")
             return False
-    
+
     def _verify_url(self, step: VerifyUrlStep) -> bool:
         """Verify the current URL."""
         try:
             current_url = self.page.url
-            
+
             if step.contains:
                 if step.url in current_url:
                     self.logger.info(f"✅ Verification passed: URL contains '{step.url}'")
@@ -405,12 +393,12 @@ class SyncFlowExecutor:
         except Exception as e:
             self.logger.error(f"❌ URL verification error: {e}")
             return False
-    
+
     def _verify_no_errors(self, step: VerifyNoErrorsStep) -> bool:
         """Verify that no error indicators are present on the page."""
         try:
             errors_found = []
-            
+
             for selector in step.error_selectors:
                 elements = self.page.query_selector_all(selector)
                 for element in elements:
@@ -418,15 +406,15 @@ class SyncFlowExecutor:
                         text = element.text_content()
                         if text and text.strip():
                             errors_found.append(f"Error found with selector '{selector}': {text.strip()}")
-            
+
             if not errors_found:
-                self.logger.info(f"✅ Verification passed: No error indicators found on page")
+                self.logger.info("✅ Verification passed: No error indicators found on page")
                 return True
             else:
-                self.logger.error(f"❌ Verification failed: Error indicators found:")
+                self.logger.error("❌ Verification failed: Error indicators found:")
                 for error in errors_found:
                     self.logger.error(f"   {error}")
                 return False
         except Exception as e:
             self.logger.error(f"❌ Error verification failed: {e}")
-            return False 
\ No newline at end of file
+            return False
