@@ -1,5 +1,6 @@
 from datetime import datetime
-from typing import List, Optional, Dict, Any, Literal
+from pathlib import Path
+from typing import List, Optional, Dict, Any
 from plato.config import get_config
 from plato.models import PlatoTask, PlatoTaskMetadata
 from plato.models.task import ScoringType
@@ -30,15 +31,24 @@ class SyncPlato:
         http_session (Optional[requests.Session]): The requests session for making HTTP requests.
     """
 
-    def __init__(self, api_key: Optional[str] = None, base_url: Optional[str] = None):
+    def __init__(
+        self,
+        api_key: Optional[str] = None,
+        base_url: Optional[str] = None,
+        feature_flags: Optional[Dict[str, Any]] = None,
+    ):
         """Initialize a new SyncPlato.
 
         Args:
             api_key (Optional[str]): The API key for authentication. If not provided,
                 falls back to the key from config.
+            base_url (Optional[str]): The base URL for the Plato API. If not provided,
+                falls back to the URL from config.
+            feature_flags (Optional[Dict[str, Any]]): Feature flags to include in all requests.
         """
         self.api_key = api_key or config.api_key
         self.base_url = base_url or config.base_url
+        self.feature_flags = feature_flags or {}
         self._http_session: Optional[requests.Session] = None
 
     @property
@@ -51,6 +61,10 @@ class SyncPlato:
         if self._http_session is None:
             self._http_session = requests.Session()
             self._http_session.headers.update({"X-API-Key": self.api_key})
+            # Attach feature flags as default cookies for all requests
+            if self.feature_flags:
+                for name, value in self.feature_flags.items():
+                    self._http_session.cookies.set(name, str(value))
         return self._http_session
 
     def close(self):
@@ -100,7 +114,6 @@ class SyncPlato:
         tag: Optional[str] = None,
         dataset: Optional[str] = None,
         artifact_id: Optional[str] = None,
-        feature_flags: Optional[Dict[str, Any]] = None,
     ) -> SyncPlatoEnvironment:
         """Create a new Plato environment for the given task.
 
@@ -144,7 +157,6 @@ class SyncPlato:
                 "dataset": dataset,
                 "artifact_id": artifact_id,
             },
-            cookies={name: str(value) for name, value in (feature_flags or {}).items()},
         )
         self._handle_response_error(response)
         data = response.json()
@@ -249,6 +261,7 @@ class SyncPlato:
         job_id: str,
         task: Optional[PlatoTask] = None,
         agent_version: Optional[str] = None,
+        model: Optional[str] = None,
         load_authenticated: bool = False,
         **kwargs,
     ) -> Dict[str, Any]:
@@ -258,6 +271,7 @@ class SyncPlato:
             job_id (str): The ID of the job to reset.
             task (Optional[PlatoTask]): Optional new task for the environment.
             agent_version (Optional[str]): Optional agent version.
+            model (Optional[str]): Optional model.
             load_authenticated (bool): Whether to load authenticated browser state.
 
         Returns:
@@ -269,6 +283,7 @@ class SyncPlato:
         body = {
             "test_case_public_id": task.public_id if task else None,
             "agent_version": agent_version,
+            "model": model,
             "load_browser_state": load_authenticated,
             **kwargs,
         }
@@ -495,7 +510,7 @@ class SyncPlato:
             requests.RequestException: If the API request fails.
         """
         response = self.http_session.get(
-            f"{self.base_url}/testcases?simulator_name={simulator_name}&page_size=1000",
+            f"{self.base_url}/testcases?simulator_name={simulator_name}&page_size=10000",
         )
         self._handle_response_error(response)
         res = response.json()
@@ -525,7 +540,10 @@ class SyncPlato:
                     capabilities=t.get("metadataConfig", {}).get("capabilities", []),
                     tags=t.get("metadataConfig", {}).get("tags", []),
                     rejected=t.get("metadataConfig", {}).get("rejected", False),
-                ) if t.get("metadataConfig") else None,
+                )
+                if t.get("metadataConfig")
+                else None,
+                version=t.get("version"),
             )
             for t in test_cases
         ]
@@ -564,3 +582,126 @@ class SyncPlato:
         )
         self._handle_response_error(response)
         return response.json()
+
+    def get_simulator_flows(self, artifact_id: str) -> List[Dict[str, Any]]:
+        """Get login flows for a simulator artifact.
+
+        This method fetches flow configurations from the API using a simulator artifact ID,
+        allowing you to retrieve login flows independently of an environment instance.
+
+        Args:
+            artifact_id (str): The simulator artifact ID to fetch flows for.
+
+        Returns:
+            List[Dict[str, Any]]: List of flow configurations parsed from the YAML response.
+
+        Raises:
+            PlatoClientError: If the API request fails or flows cannot be parsed.
+            requests.RequestException: If the API request fails.
+
+        Example:
+            ```python
+            client = SyncPlato()
+            flows = client.get_simulator_flows("artifact_123")
+            # Use the flows for authentication
+            ```
+        """
+        import yaml
+        import json
+
+        try:
+            headers = {"X-API-Key": self.api_key}
+            response = self.http_session.get(
+                f"{self.base_url}/simulator/{artifact_id}/flows", headers=headers
+            )
+            self._handle_response_error(response)
+            body_text = response.text
+
+            # Endpoint may return JSON with { data: { flows: "...yaml..." } } or raw YAML
+            try:
+                parsed = json.loads(body_text)
+                flows_yaml = (
+                    parsed.get("data", {}).get("flows")
+                    if isinstance(parsed, dict)
+                    else None
+                )
+                if not flows_yaml:
+                    raise ValueError("flows missing in JSON body")
+            except Exception:
+                flows_yaml = body_text
+
+            scripts = yaml.safe_load(flows_yaml)
+            flows_data = scripts.get("flows", [])
+            return flows_data
+        except Exception as e:
+            raise PlatoClientError(f"Failed to load flows from API: {e}")
+
+    def login_artifact(
+        self,
+        artifact_id: str,
+        page,
+        throw_on_login_error: bool = False,
+        screenshots_dir: Optional[Path] = None,
+        dataset: str = "base",
+    ) -> None:
+        """Login using flows from a simulator artifact.
+
+        This method fetches flow configurations from the API using a simulator artifact ID
+        and executes the login flow on the provided Playwright page. This is independent
+        of any environment instance.
+
+        Args:
+            artifact_id (str): The simulator artifact ID to fetch flows for.
+            page: The Playwright page to authenticate (sync_api.Page).
+            throw_on_login_error (bool): Whether to raise an error on login failure.
+            screenshots_dir (Optional[Path]): Directory to store screenshots during the flow.
+            dataset (str): The dataset/flow name to use for login (default: "base", which maps to "login").
+
+        Raises:
+            PlatoClientError: If flows cannot be fetched, parsed, or executed.
+
+        Example:
+            ```python
+            from plato.sync_sdk import SyncPlato
+            from playwright.sync_api import sync_playwright
+
+            client = SyncPlato()
+            with sync_playwright() as p:
+                browser = p.chromium.launch()
+                page = browser.new_page()
+                client.login_artifact("artifact_123", page)
+                # Page is now authenticated
+            ```
+        """
+        from plato.sync_flow_executor import SyncFlowExecutor
+        from plato.models.flow import Flow
+
+        try:
+            flows_data = self.get_simulator_flows(artifact_id)
+            flows_list = [Flow.model_validate(f) for f in flows_data]
+
+            # Determine flow name based on dataset
+            if dataset == "base":
+                flow_name = "login"
+            else:
+                flow_name = dataset
+
+            login_flow = next(
+                (flow for flow in flows_list if flow.name == flow_name), None
+            )
+            if not login_flow:
+                raise PlatoClientError(f"No login flow '{flow_name}' found")
+
+            flow_executor = SyncFlowExecutor(
+                page, login_flow, logger=logger, screenshots_dir=screenshots_dir
+            )
+            if not flow_executor.execute_flow():
+                if throw_on_login_error:
+                    raise PlatoClientError("Failed to login")
+                else:
+                    logger.warning("Failed to login")
+        except Exception as e:
+            if throw_on_login_error:
+                raise PlatoClientError(f"Login failed: {e}")
+            else:
+                logger.error(f"Login failed: {e}")
