@@ -3,6 +3,7 @@ import os
 import platform
 import shutil
 import subprocess
+from pathlib import Path
 from typing import Optional
 
 
@@ -14,9 +15,44 @@ def is_command_available(cmd: str) -> bool:
 
 
 def find_proxytunnel_path() -> Optional[str]:
+    """Find proxytunnel binary. Checks bundled binaries first, then system PATH."""
+
+    # First, check for bundled binary in the package
+    package_dir = Path(__file__).resolve().parent.parent  # plato/utils -> plato
+
+    # Determine platform-specific binary name
+    system = platform.system().lower()
+    machine = platform.machine().lower()
+
+    # Map platform to binary name
+    if system == "darwin":
+        if machine in ("arm64", "aarch64"):
+            binary_name = "proxytunnel-darwin-arm64"
+        else:
+            binary_name = "proxytunnel-darwin-amd64"
+    elif system == "linux":
+        if machine in ("aarch64", "arm64"):
+            binary_name = "proxytunnel-linux-arm64"
+        else:
+            binary_name = "proxytunnel-linux-amd64"
+    elif system == "windows":
+        binary_name = "proxytunnel.exe"
+    else:
+        binary_name = None
+
+    # Check bundled binary
+    if binary_name:
+        bundled_path = package_dir / "bin" / binary_name
+        if bundled_path.exists() and os.access(bundled_path, os.X_OK):
+            logger.debug(f"Found bundled proxytunnel at {bundled_path}")
+            return str(bundled_path)
+
+    # Fall back to system PATH
     path = shutil.which("proxytunnel")
     if path:
+        logger.debug(f"Found proxytunnel in PATH at {path}")
         return path
+
     # Common install locations
     for candidate in (
         "/opt/homebrew/bin/proxytunnel",
@@ -25,7 +61,9 @@ def find_proxytunnel_path() -> Optional[str]:
         "/bin/proxytunnel",
     ):
         if os.path.exists(candidate):
+            logger.debug(f"Found proxytunnel at {candidate}")
             return candidate
+
     return None
 
 
@@ -35,8 +73,9 @@ def install_proxytunnel_noninteractive() -> bool:
     Returns True on success, False otherwise. Avoids interactive prompts.
     """
     try:
-        if is_command_available("proxytunnel"):
-            logger.info("proxytunnel is already installed")
+        # Check if bundled or system proxytunnel is available
+        if find_proxytunnel_path():
+            logger.info("proxytunnel is already available (bundled or system)")
             return True
 
         system = platform.system().lower()
@@ -106,13 +145,14 @@ def install_proxytunnel_noninteractive() -> bool:
             )
             return False
 
-        # Verify installation
-        if not is_command_available("proxytunnel"):
-            logger.error("proxytunnel not found in PATH after installation")
+        # Verify installation - check if bundled or system proxytunnel is available
+        proxytunnel_path = find_proxytunnel_path()
+        if not proxytunnel_path:
+            logger.error("proxytunnel not found after installation")
             return False
 
         # Quick sanity check
-        check = subprocess.run(["proxytunnel", "-h"], capture_output=True, text=True)
+        check = subprocess.run([proxytunnel_path, "-h"], capture_output=True, text=True)
         if check.returncode not in (0, 1):  # -h may exit 1 depending on build
             logger.warning(
                 "proxytunnel installed but health check returned %s", check.returncode
